@@ -5,6 +5,6 @@ lindley.mle <- function(x) {
   b <- a - 1
   delta <- b^2 + 8 * a
   theta <-  0.5 * ( - b + sqrt(delta) ) / a
-  loglik <- 2 * n * log(theta) - n * log(1 + theta) + sum( log(1 + x) ) - theta * sx
+  loglik <- 2 * n * log(theta) - n * log(1 + theta) + sum( log1p(x) ) - theta * sx
   list(loglik = loglik, theta = theta)
 }
