@@ -1,6 +1,6 @@
 mvkurtosis <- function(x) {
   n <- dim(x)[1]
-  m <- colmeans(x)
+  m <- Rfast::colmeans(x)
   s <- (crossprod(x) - n * tcrossprod(m))/(n - 1)
-  sum( mahala(x, m, s)^2 ) / n 
+  sum( Rfast::mahala(x, m, s)^2 ) / n 
 }
\ No newline at end of file
