@@ -1,5 +1,5 @@
 pois.test <- function(y, logged = FALSE) {
-  stat <- ( Var(y)/mean(y) - 1) * sqrt( 0.5 *(length(y) - 1) )
+  stat <- ( Rfast::Var(y)/mean(y) - 1) * sqrt( 0.5 * (length(y) - 1) )
   pval <- 2 * pnorm(abs(stat), lower.tail = FALSE, log.p = logged)
   c(stat, pval)
 }
\ No newline at end of file
