@@ -1,6 +1,6 @@
 poisson.nb <- function (xnew, x, ina) {
     nu <- tabulate(ina)
     m <- rowsum(x, ina)/nu
-    score <-  -Rfast::rowsums(m) + tcrossprod(log(m), xnew)
+    score <- tcrossprod(log(m), xnew) - Rfast::rowsums(m)
     colMaxs(score)
 }
