@@ -1,7 +1,7 @@
 
 
 varcomps.mle <- function(x,ina,tol=1e-09) {
-	mat<-.Call('Rfast_varcomps_mle',x,ina,sort_unique.length(ina),tol)
+	mat<-.Call('Rfast_varcomps_mle',x,ina,Rfast::sort_unique.length(ina),tol)
 	syina<-mat$syina
 	mat<-mat$mat
 	d=mat[4]
