@@ -16,6 +16,7 @@ static SEXP eachrow(SEXP x,SEXP y,const char oper){
     case '+': return eachrow_helper< madd<double> >(x,y);
     case '/': return eachrow_helper< mdiv<double> >(x,y);
     case '-': return eachrow_helper< mdiff<double> >(x,y);
+    case '^': return eachrow_helper<std::pow >(x,y);
     default: stop("The operation doesn't supported.");
   }
   return R_NilValue;
@@ -28,6 +29,7 @@ static double apply_eachrow(SEXP x,SEXP y,const char oper,const string method){
       case '+': return apply_eachrow_helper<madd<double>,madd<double> >(x,y);
       case '/': return apply_eachrow_helper<mdiv<double>,madd<double> >(x,y);
       case '-': return apply_eachrow_helper<mdiff<double>,madd<double> >(x,y);
+      case '^': return apply_eachrow_helper<std::pow,madd<double> >(x,y);
       default: stop("The operation doesn't supported.");
     }
   }else if(method == "min"){
@@ -36,6 +38,7 @@ static double apply_eachrow(SEXP x,SEXP y,const char oper,const string method){
       case '+': return apply_eachrow_helper<madd<double>,mmin<double> >(x,y);
       case '/': return apply_eachrow_helper<mdiv<double>,mmin<double> >(x,y);
       case '-': return apply_eachrow_helper<mdiff<double>,mmin<double> >(x,y);
+      case '^': return apply_eachrow_helper<std::pow,mmin<double> >(x,y);
       default: stop("The operation doesn't supported.");
     }
   }else if(method == "max"){
@@ -44,6 +47,7 @@ static double apply_eachrow(SEXP x,SEXP y,const char oper,const string method){
       case '+': return apply_eachrow_helper<madd<double>,mmax<double> >(x,y);
       case '/': return apply_eachrow_helper<mdiv<double>,mmax<double> >(x,y);
       case '-': return apply_eachrow_helper<mdiff<double>,mmax<double> >(x,y);
+      case '^': return apply_eachrow_helper<std::pow,mmax<double> >(x,y);
       default: stop("The operation doesn't supported.");
     }
   }
