@@ -2,7 +2,7 @@
 
 #include <RcppArmadillo.h>
 #include <algorithm>
-
+#include "mn.h"
 using namespace Rcpp;
 using std::nth_element;
 using std::remove_if;
@@ -51,6 +51,59 @@ static double nth_na_rm(NumericVector& X,const int& elem,const bool& descend){
   	return x[elem-1];
 }
 
+int nth_int(vector<int> x,int elem){
+    int aa,mx,mn;
+    bool has_pos=false,has_neg=false;
+    max_neg_pos(&x[0],&x[x.size()-1]+1,mx,mn,has_pos,has_neg);
+    vector<int> pos,f(x.size()),neg;
+    vector<int>::iterator a=x.begin();
+    vector<int>::reverse_iterator F=f.rbegin();
+    if(has_pos){
+        pos.resize(mx+1,0);
+    }
+    if(has_neg){
+        neg.resize(1-mn,0);
+    }
+    if(has_pos && has_neg){
+        for(;a!=x.end();++a){
+            aa=*a;
+            aa<0 ? neg[-aa]++ : pos[aa]++;
+        }
+    }else if(has_pos){
+        for(;a!=x.end();++a){
+            aa=*a;
+            pos[aa]++;
+        }
+    }else{ 
+        for(;a!=x.end();++a){
+            aa=*a;
+            neg[-aa]++;
+        }
+    }
+    
+    --elem;
+    int res=0,num=0;
+    if(has_neg){
+        for(vector<int>::reverse_iterator nr=neg.rbegin();nr!=neg.rend();++nr){
+            if(*nr!=0){
+                num+=*nr;
+                if(elem>num)
+                    res=nr-neg.rbegin()+1;        
+            }
+        }
+    }
+    if(has_pos){
+        for(a=pos.begin();a!=pos.end();++a){
+            if(*a!=0){
+                num+=*a;
+                if(elem>num)
+                    res=a-pos.begin()+1;
+            }
+        }
+    }
+    return res;
+}
+
 double nth(NumericVector x,const int elem,const bool descend,const bool na_rm){
 	return na_rm ? nth_na_rm(x,elem,descend) : nth_simple(x,elem,descend);
 }
@@ -73,6 +126,18 @@ BEGIN_RCPP
 END_RCPP
 }
 
+// nth_int
+RcppExport SEXP Rfast_nth_int(SEXP xSEXP,SEXP elemSEXP) {
+BEGIN_RCPP
+    RObject __result;
+    RNGScope __rngScope;
+    traits::input_parameter< vector<int> >::type x(xSEXP);
+    traits::input_parameter< int >::type elem(elemSEXP);
+    __result = nth_int(x,elem);
+    return __result;
+END_RCPP
+}
+
 // nth_index
 RcppExport SEXP Rfast_nth_index(SEXP xSEXP,SEXP elemSEXP,SEXP descendSEXP,SEXP na_rmSEXP) {
 BEGIN_RCPP
